@@ -12,9 +12,9 @@ def create_file_chunks(bucket_name, file_pattern, job_uuid, file_headers, integr
     start = datetime.utcnow().timestamp()
     chunk_pointer = None
     chunk_writer = None
-    delivered_pointer = None
-    delivered_writer = None
-    delivered_file_path = ''
+    delivered_pointers = None
+    delivered_writers = None
+    delivered_file_paths = dict()
     checkpoint = get_file_checkpoint(file_pattern=file_pattern, job_uuid=job_uuid)
     if checkpoint is not None:
         chunk_number = checkpoint['chunk_number'] + 1
@@ -32,33 +32,38 @@ def create_file_chunks(bucket_name, file_pattern, job_uuid, file_headers, integr
             chunk_number=chunk_number,
             writer=chunk_writer,
             pointer=chunk_pointer)
-        delivered_file_path, delivered_pointer, delivered_writer = add_row_to_delivered_path(
-            job_uuid=job_uuid, file_headers=file_headers, row=row, pointer=delivered_pointer,
-            writer=delivered_writer,
+        delivered_file_paths, delivered_pointers, delivered_writers = add_row_to_delivered_path(
+            job_uuid=job_uuid, file_headers=file_headers, row=row, pointers=delivered_pointers,
+            writers=delivered_writers, delivered_paths=delivered_file_paths,
             chunk_number=chunk_number, timestamp=start)
         chunk_records += 1
         if 0 < integration_settings['chunk_size'] <= chunk_records:
             chunk_pointer.close()
             chunk_pointer = None
-            delivered_pointer.close()
-            delivered_pointer = None
-            yield chunk_file_path, delivered_file_path, chunk_number
+            for segment_uuid in delivered_pointers.keys():
+                delivered_pointers[segment_uuid].close()
+            delivered_pointers = None
+            delivered_writers = None
+            yield chunk_file_path, delivered_file_paths, chunk_number
             update_file_checkpoint(job_uuid=job_uuid, file_pattern=file_pattern, chunk_number=chunk_number,
                                    line_number=line_number, file_path=file_path)
             start = datetime.utcnow().timestamp()
             os.remove(chunk_file_path)
-            os.remove(delivered_file_path)
+            for segment_uuid in delivered_file_paths.keys():
+                os.remove(delivered_file_paths[segment_uuid])
             chunk_records = 0
             chunk_number += 1
 
     if chunk_records > 0:
         chunk_pointer.close()
-        delivered_pointer.close()
-        yield chunk_file_path, delivered_file_path, chunk_number
+        for segment_uuid in delivered_pointers.keys():
+            delivered_pointers[segment_uuid].close()
+        yield chunk_file_path, delivered_file_paths, chunk_number
         update_file_checkpoint(job_uuid=job_uuid, file_pattern=file_pattern, chunk_number=chunk_number,
                                line_number=line_number, file_path=file_path)
         os.remove(chunk_file_path)
-        os.remove(delivered_file_path)
+        for segment_uuid in delivered_file_paths.keys():
+            os.remove(delivered_file_paths[segment_uuid])
 
 
 def add_row_to_chunk(row, chunk_number, job_uuid, file_headers, delimiter, pointer=None, writer=None):
@@ -72,17 +77,24 @@ def add_row_to_chunk(row, chunk_number, job_uuid, file_headers, delimiter, point
                        writer=writer)
 
 
-def add_row_to_delivered_path(row, chunk_number, job_uuid, file_headers, timestamp, pointer=None,
-                              writer=None):
+def add_row_to_delivered_path(row, chunk_number, job_uuid, file_headers, timestamp, pointers=None,
+                              writers=None, delivered_paths=None):
     from stratus_api.core.settings import get_settings
     import os
     delivered_path_pattern = os.path.join(get_settings().get('upload_folder', '/apps/files/'),
-                                          'delivered-{job_uuid}-{chunk_number}.csv')
-    delivered_path = delivered_path_pattern.format(chunk_number=chunk_number, job_uuid=job_uuid)
+                                          'delivered-{segment_uuid}-{job_uuid}-{chunk_number}.csv')
+
+    if pointers is None:
+        pointers = dict()
+        writers = dict()
+        delivered_paths = dict()
+
     for segment_uuid, operation in {k: row[idx] for idx, k in enumerate(file_headers) if
                                     k not in ['internal_user_id', 'external_user_id', 'id_type', 'policy_uuid',
                                               'created_ts'] and row[
                                         idx] != ''}.items():
+        delivered_path = delivered_path_pattern.format(chunk_number=chunk_number, job_uuid=job_uuid,
+                                                       segment_uuid=segment_uuid)
         delivered_path, pointer, writer = add_to_file(
             path=delivered_path, row=[
                 segment_uuid,
@@ -94,10 +106,13 @@ def add_row_to_delivered_path(row, chunk_number, job_uuid, file_headers, timesta
                 row[file_headers.index('policy_uuid')],
                 timestamp
             ], headers=delivered_headers, delimiter=',',
-            pointer=pointer,
-            writer=writer,
+            pointer=pointers.get(segment_uuid),
+            writer=writers.get(segment_uuid),
         )
-    return delivered_path, pointer, writer
+        delivered_paths[segment_uuid] = delivered_path
+        pointers[segment_uuid]=pointer
+        writers[segment_uuid]=writer
+    return delivered_paths, pointers, writers
 
 
 def add_to_file(path, row, headers, delimiter, pointer, writer, add_headers=True):
